==> AsposeCellsCloud-CellsApi-25.12.tar.gz: AsposeCellsCloud-CellsApi-25.12/docs/model/HtmlSaveOptions.md <==
# AsposeCellsCloud::Object::HtmlSaveOptions 

## Load the model package
```perl
use AsposeCellsCloud::Object::HtmlSaveOptions;
```

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**ExportPageHeaders** | **boolean** |  |
**ExportPageFooters** | **boolean** |  |
**ExportRowColumnHeadings** | **boolean** |  |
**ShowAllSheets** | **boolean** |  |
**ImageOptions** | **ImageOrPrintOptions** |  |
**SaveAsSingleFile** | **boolean** |  |
**ExportHiddenWorksheet** | **boolean** |  |
**ExportGridLines** | **boolean** |  |
**PresentationPreference** | **boolean** |  |
**CellCssPrefix** | **string** |  |
**TableCssId** | **string** |  |
**IsFullPathLink** | **boolean** |  |
**ExportWorksheetCSSSeparately** | **boolean** |  |
**ExportSimilarBorderStyle** | **boolean** |  |
**MergeEmptyTdForcely** | **boolean** |  |
**ExportCellCoordinate** | **boolean** |  |
**ExportExtraHeadings** | **boolean** |  |
**ExportHeadings** | **boolean** |  |
**ExportFormula** | **boolean** |  |
**AddTooltipText** | **boolean** |  |
**ExportBogusRowData** | **boolean** |  |
**ExcludeUnusedStyles** | **boolean** |  |
**ExportDocumentProperties** | **boolean** |  |
**ExportWorksheetProperties** | **boolean** |  |
**ExportWorkbookProperties** | **boolean** |  |
**ExportFrameScriptsAndProperties** | **boolean** |  |
**AttachedFilesDirectory** | **string** |  |
**AttachedFilesUrlPrefix** | **string** |  |
**Encoding** | **string** |  |
**ExportActiveWorksheetOnly** | **boolean** |  |
**ExportChartImageFormat** | **string** |  |
**ExportImagesAsBase64** | **boolean** |  |
**HiddenColDisplayType** | **string** |  |
**HiddenRowDisplayType** | **string** |  |
**HtmlCrossStringType** | **string** |  |
**IsExpImageToTempDir** | **boolean** |  |
**PageTitle** | **string** |  |
**ParseHtmlTagInCell** | **boolean** |  |
**CellNameAttribute** | **string** |  |
**SaveFormat** | **string** |  |
**CachedFileFolder** | **string** |  |
**ClearData** | **boolean** |  |
**CreateDirectory** | **boolean** |  |
**EnableHTTPCompression** | **boolean** |  |
**RefreshChartCache** | **boolean** |  |
**SortNames** | **boolean** |  |
**ValidateMergedAreas** | **boolean** |  |
**MergeAreas** | **boolean** |  |
**SortExternalNames** | **boolean** |  |
**CheckExcelRestriction** | **boolean** |  |
**UpdateSmartArt** | **boolean** |  |
**EncryptDocumentProperties** | **boolean** |  |  

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

==> AsposeCellsCloud-CellsApi-26.2.tar.gz: AsposeCellsCloud-CellsApi-26.2/docs/model/HtmlSaveOptions.md <==
# AsposeCellsCloud::Object::HtmlSaveOptions 

## Load the model package
```perl
use AsposeCellsCloud::Object::HtmlSaveOptions;
```

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**ExportPageHeaders** | **boolean** |  |
**ExportPageFooters** | **boolean** |  |
**ExportRowColumnHeadings** | **boolean** |  |
**ShowAllSheets** | **boolean** |  |
**ImageOptions** | **ImageOrPrintOptions** |  |
**SaveAsSingleFile** | **boolean** |  |
**ExportHiddenWorksheet** | **boolean** |  |
**ExportGridLines** | **boolean** |  |
**PresentationPreference** | **boolean** |  |
**CellCssPrefix** | **string** |  |
**TableCssId** | **string** |  |
**IsFullPathLink** | **boolean** |  |
**ExportWorksheetCSSSeparately** | **boolean** |  |
**ExportSimilarBorderStyle** | **boolean** |  |
**MergeEmptyTdForcely** | **boolean** |  |
**ExportCellCoordinate** | **boolean** |  |
**ExportExtraHeadings** | **boolean** |  |
**ExportHeadings** | **boolean** |  |
**ExportFormula** | **boolean** |  |
**AddTooltipText** | **boolean** |  |
**ExportBogusRowData** | **boolean** |  |
**ExcludeUnusedStyles** | **boolean** |  |
**ExportDocumentProperties** | **boolean** |  |
**ExportWorksheetProperties** | **boolean** |  |
**ExportWorkbookProperties** | **boolean** |  |
**ExportFrameScriptsAndProperties** | **boolean** |  |
**AttachedFilesDirectory** | **string** |  |
**AttachedFilesUrlPrefix** | **string** |  |
**Encoding** | **string** |  |
**ExportActiveWorksheetOnly** | **boolean** |  |
**ExportChartImageFormat** | **string** |  |
**ExportImagesAsBase64** | **boolean** |  |
**HiddenColDisplayType** | **string** |  |
**HiddenRowDisplayType** | **string** |  |
**HtmlCrossStringType** | **string** |  |
**IsExpImageToTempDir** | **boolean** |  |
**PageTitle** | **string** |  |
**ParseHtmlTagInCell** | **boolean** |  |
**CellNameAttribute** | **string** |  |
**SaveFormat** | **string** |  |
**CachedFileFolder** | **string** |  |
**ClearData** | **boolean** |  |
**CreateDirectory** | **boolean** |  |
**EnableHTTPCompression** | **boolean** |  |
**RefreshChartCache** | **boolean** |  |
**SortNames** | **boolean** |  |
**ValidateMergedAreas** | **boolean** |  |
**MergeAreas** | **boolean** |  |
**SortExternalNames** | **boolean** |  |
**CheckExcelRestriction** | **boolean** |  |
**UpdateSmartArt** | **boolean** |  |
**EncryptDocumentProperties** | **boolean** |  |  


[[Back to Model list]](../DeveloperGuide.md#model-reference)  
[[Back to README]](../../README.md)
